@@ -167,7 +167,7 @@ int init_uwsgi_app(int loader, void *arg1, struct wsgi_request *wsgi_req, PyThre
 		PyThreadState_Swap(wi->interpreter);
 		init_pyargv();
 
-		// we need to inizialize an embedded module for every interpreter
+		// we need to initialize an embedded module for every interpreter
 		init_uwsgi_embedded_module();
 		init_uwsgi_vars();
 
@@ -205,7 +205,7 @@ int init_uwsgi_app(int loader, void *arg1, struct wsgi_request *wsgi_req, PyThre
 		app_list = PyDict_Keys(applications);
 		multiapp = PyList_Size(app_list);
 		if (multiapp < 1) {
-			uwsgi_log("you have to define at least one app in the apllications dictionary\n");
+			uwsgi_log("you have to define at least one app in the applications dictionary\n");
 			goto doh;
 		}		
 
@@ -340,9 +340,11 @@ int init_uwsgi_app(int loader, void *arg1, struct wsgi_request *wsgi_req, PyThre
 
 	const char *default_app = "";
 
-	if ((wsgi_req->appid_len == 0 || (wsgi_req->appid_len = 1 && wsgi_req->appid[0] == '/')) && uwsgi.default_app == -1) {
-		default_app = " (default app)" ;
-		uwsgi.default_app = id;
+	if (!uwsgi.no_default_app) {
+		if ((wsgi_req->appid_len == 0 || (wsgi_req->appid_len = 1 && wsgi_req->appid[0] == '/')) && uwsgi.default_app == -1) {
+			default_app = " (default app)" ;
+			uwsgi.default_app = id;
+		}
 	}
 
 	wi->started_at = now;
