@@ -95,6 +95,11 @@ static void stats_pusher_statsd(struct uwsgi_stats_pusher_instance *uspi, time_t
 			statsd_send_metric(ub, uspi, um->name, um->name_len, *um->value, "|m");
 		}
 		uwsgi_rwunlock(uwsgi.metrics_lock);
+		if (um->reset_after_push){
+			uwsgi_wlock(uwsgi.metrics_lock);
+			*um->value = um->initial_value;
+			uwsgi_rwunlock(uwsgi.metrics_lock);
+		}
 		um = um->next;
 	}
 	uwsgi_buffer_destroy(ub);
